# Go API client for spacetraders

SpaceTraders is an open-universe game and learning platform that offers a set of HTTP endpoints to control a fleet of ships and explore a multiplayer universe.

The API is documented using [OpenAPI](https://github.com/SpaceTradersAPI/api-docs). You can send your first request right here in your browser to check the status of the game server.

```json http
{
  \"method\": \"GET\",
  \"url\": \"https://api.spacetraders.io/v2\",
}
```

Unlike a traditional game, SpaceTraders does not have a first-party client or app to play the game. Instead, you can use the API to build your own client, write a script to automate your ships, or try an app built by the community.

We have a [Discord channel](https://discord.com/invite/jh6zurdWk5) where you can share your projects, ask questions, and get help from other players.




## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [OpenAPI-spec](https://www.openapis.org/) from a remote server, you can easily generate an API client.

- API version: 2.0.0
- Package version: 2.0.0
- Build package: org.openapitools.codegen.languages.GoClientCodegen

## Installation

Install the following dependencies:

```shell
go get github.com/stretchr/testify/assert
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```golang
import spacetraders "git.siteop.biz/spacetraders/spacetraders"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```golang
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `sw.ContextServerIndex` of type `int`.

```golang
ctx := context.WithValue(context.Background(), spacetraders.ContextServerIndex, 1)
```

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `sw.ContextServerVariables` of type `map[string]string`.

```golang
ctx := context.WithValue(context.Background(), spacetraders.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `sw.ContextOperationServerIndices` and `sw.ContextOperationServerVariables` context maps.

```golang
ctx := context.WithValue(context.Background(), spacetraders.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), spacetraders.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

## Documentation for API Endpoints

All URIs are relative to *https://api.spacetraders.io/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AgentsApi* | [**GetMyAgent**](docs/AgentsApi.md#getmyagent) | **Get** /my/agent | My Agent Details
*ContractsApi* | [**AcceptContract**](docs/ContractsApi.md#acceptcontract) | **Post** /my/contracts/{contractId}/accept | Accept Contract
*ContractsApi* | [**DeliverContract**](docs/ContractsApi.md#delivercontract) | **Post** /my/contracts/{contractId}/deliver | Deliver Contract
*ContractsApi* | [**FulfillContract**](docs/ContractsApi.md#fulfillcontract) | **Post** /my/contracts/{contractId}/fulfill | Fulfill Contract
*ContractsApi* | [**GetContract**](docs/ContractsApi.md#getcontract) | **Get** /my/contracts/{contractId} | Get Contract
*ContractsApi* | [**GetContracts**](docs/ContractsApi.md#getcontracts) | **Get** /my/contracts | List Contracts
*DefaultApi* | [**Register**](docs/DefaultApi.md#register) | **Post** /register | Register New Agent
*FactionsApi* | [**GetFaction**](docs/FactionsApi.md#getfaction) | **Get** /factions/{factionSymbol} | Get Faction
*FactionsApi* | [**GetFactions**](docs/FactionsApi.md#getfactions) | **Get** /factions | List Factions
*FleetApi* | [**CreateChart**](docs/FleetApi.md#createchart) | **Post** /my/ships/{shipSymbol}/chart | Create Chart
*FleetApi* | [**CreateShipShipScan**](docs/FleetApi.md#createshipshipscan) | **Post** /my/ships/{shipSymbol}/scan/ships | Scan Ships
*FleetApi* | [**CreateShipSystemScan**](docs/FleetApi.md#createshipsystemscan) | **Post** /my/ships/{shipSymbol}/scan/systems | Scan Systems
*FleetApi* | [**CreateShipWaypointScan**](docs/FleetApi.md#createshipwaypointscan) | **Post** /my/ships/{shipSymbol}/scan/waypoints | Scan Waypoints
*FleetApi* | [**CreateSurvey**](docs/FleetApi.md#createsurvey) | **Post** /my/ships/{shipSymbol}/survey | Create Survey
*FleetApi* | [**DockShip**](docs/FleetApi.md#dockship) | **Post** /my/ships/{shipSymbol}/dock | Dock Ship
*FleetApi* | [**ExtractResources**](docs/FleetApi.md#extractresources) | **Post** /my/ships/{shipSymbol}/extract | Extract Resources
*FleetApi* | [**GetMyShip**](docs/FleetApi.md#getmyship) | **Get** /my/ships/{shipSymbol} | Get Ship
*FleetApi* | [**GetMyShipCargo**](docs/FleetApi.md#getmyshipcargo) | **Get** /my/ships/{shipSymbol}/cargo | Get Ship Cargo
*FleetApi* | [**GetMyShips**](docs/FleetApi.md#getmyships) | **Get** /my/ships | List Ships
*FleetApi* | [**GetShipCooldown**](docs/FleetApi.md#getshipcooldown) | **Get** /my/ships/{shipSymbol}/cooldown | Get Ship Cooldown
*FleetApi* | [**GetShipNav**](docs/FleetApi.md#getshipnav) | **Get** /my/ships/{shipSymbol}/nav | Get Ship Nav
*FleetApi* | [**Jettison**](docs/FleetApi.md#jettison) | **Post** /my/ships/{shipSymbol}/jettison | Jettison Cargo
*FleetApi* | [**JumpShip**](docs/FleetApi.md#jumpship) | **Post** /my/ships/{shipSymbol}/jump | Jump Ship
*FleetApi* | [**NavigateShip**](docs/FleetApi.md#navigateship) | **Post** /my/ships/{shipSymbol}/navigate | Navigate Ship
*FleetApi* | [**OrbitShip**](docs/FleetApi.md#orbitship) | **Post** /my/ships/{shipSymbol}/orbit | Orbit Ship
*FleetApi* | [**PatchShipNav**](docs/FleetApi.md#patchshipnav) | **Patch** /my/ships/{shipSymbol}/nav | Patch Ship Nav
*FleetApi* | [**PurchaseCargo**](docs/FleetApi.md#purchasecargo) | **Post** /my/ships/{shipSymbol}/purchase | Purchase Cargo
*FleetApi* | [**PurchaseShip**](docs/FleetApi.md#purchaseship) | **Post** /my/ships | Purchase Ship
*FleetApi* | [**RefuelShip**](docs/FleetApi.md#refuelship) | **Post** /my/ships/{shipSymbol}/refuel | Refuel Ship
*FleetApi* | [**SellCargo**](docs/FleetApi.md#sellcargo) | **Post** /my/ships/{shipSymbol}/sell | Sell Cargo
*FleetApi* | [**ShipRefine**](docs/FleetApi.md#shiprefine) | **Post** /my/ships/{shipSymbol}/refine | Ship Refine
*FleetApi* | [**TransferCargo**](docs/FleetApi.md#transfercargo) | **Post** /my/ships/{shipSymbol}/transfer | Transfer Cargo
*FleetApi* | [**WarpShip**](docs/FleetApi.md#warpship) | **Post** /my/ships/{shipSymbol}/warp | Warp Ship
*SystemsApi* | [**GetJumpGate**](docs/SystemsApi.md#getjumpgate) | **Get** /systems/{systemSymbol}/waypoints/{waypointSymbol}/jump-gate | Get Jump Gate
*SystemsApi* | [**GetMarket**](docs/SystemsApi.md#getmarket) | **Get** /systems/{systemSymbol}/waypoints/{waypointSymbol}/market | Get Market
*SystemsApi* | [**GetShipyard**](docs/SystemsApi.md#getshipyard) | **Get** /systems/{systemSymbol}/waypoints/{waypointSymbol}/shipyard | Get Shipyard
*SystemsApi* | [**GetSystem**](docs/SystemsApi.md#getsystem) | **Get** /systems/{systemSymbol} | Get System
*SystemsApi* | [**GetSystemWaypoints**](docs/SystemsApi.md#getsystemwaypoints) | **Get** /systems/{systemSymbol}/waypoints | List Waypoints
*SystemsApi* | [**GetSystems**](docs/SystemsApi.md#getsystems) | **Get** /systems | List Systems
*SystemsApi* | [**GetWaypoint**](docs/SystemsApi.md#getwaypoint) | **Get** /systems/{systemSymbol}/waypoints/{waypointSymbol} | Get Waypoint


## Documentation For Models

 - [AcceptContract200Response](docs/AcceptContract200Response.md)
 - [AcceptContract200ResponseData](docs/AcceptContract200ResponseData.md)
 - [Agent](docs/Agent.md)
 - [Chart](docs/Chart.md)
 - [ConnectedSystem](docs/ConnectedSystem.md)
 - [Contract](docs/Contract.md)
 - [ContractDeliverGood](docs/ContractDeliverGood.md)
 - [ContractPayment](docs/ContractPayment.md)
 - [ContractTerms](docs/ContractTerms.md)
 - [Cooldown](docs/Cooldown.md)
 - [CreateChart201Response](docs/CreateChart201Response.md)
 - [CreateChart201ResponseData](docs/CreateChart201ResponseData.md)
 - [CreateShipShipScan201Response](docs/CreateShipShipScan201Response.md)
 - [CreateShipShipScan201ResponseData](docs/CreateShipShipScan201ResponseData.md)
 - [CreateShipSystemScan201Response](docs/CreateShipSystemScan201Response.md)
 - [CreateShipSystemScan201ResponseData](docs/CreateShipSystemScan201ResponseData.md)
 - [CreateShipWaypointScan201Response](docs/CreateShipWaypointScan201Response.md)
 - [CreateShipWaypointScan201ResponseData](docs/CreateShipWaypointScan201ResponseData.md)
 - [CreateSurvey201Response](docs/CreateSurvey201Response.md)
 - [CreateSurvey201ResponseData](docs/CreateSurvey201ResponseData.md)
 - [DeliverContract200Response](docs/DeliverContract200Response.md)
 - [DeliverContract200ResponseData](docs/DeliverContract200ResponseData.md)
 - [DeliverContractRequest](docs/DeliverContractRequest.md)
 - [DockShip200Response](docs/DockShip200Response.md)
 - [ExtractResources201Response](docs/ExtractResources201Response.md)
 - [ExtractResources201ResponseData](docs/ExtractResources201ResponseData.md)
 - [ExtractResourcesRequest](docs/ExtractResourcesRequest.md)
 - [Extraction](docs/Extraction.md)
 - [ExtractionYield](docs/ExtractionYield.md)
 - [Faction](docs/Faction.md)
 - [FactionTrait](docs/FactionTrait.md)
 - [FulfillContract200Response](docs/FulfillContract200Response.md)
 - [GetContract200Response](docs/GetContract200Response.md)
 - [GetContracts200Response](docs/GetContracts200Response.md)
 - [GetFaction200Response](docs/GetFaction200Response.md)
 - [GetFactions200Response](docs/GetFactions200Response.md)
 - [GetJumpGate200Response](docs/GetJumpGate200Response.md)
 - [GetMarket200Response](docs/GetMarket200Response.md)
 - [GetMyAgent200Response](docs/GetMyAgent200Response.md)
 - [GetMyShip200Response](docs/GetMyShip200Response.md)
 - [GetMyShipCargo200Response](docs/GetMyShipCargo200Response.md)
 - [GetMyShips200Response](docs/GetMyShips200Response.md)
 - [GetShipCooldown200Response](docs/GetShipCooldown200Response.md)
 - [GetShipNav200Response](docs/GetShipNav200Response.md)
 - [GetShipyard200Response](docs/GetShipyard200Response.md)
 - [GetSystem200Response](docs/GetSystem200Response.md)
 - [GetSystemWaypoints200Response](docs/GetSystemWaypoints200Response.md)
 - [GetSystems200Response](docs/GetSystems200Response.md)
 - [GetWaypoint200Response](docs/GetWaypoint200Response.md)
 - [Jettison200Response](docs/Jettison200Response.md)
 - [Jettison200ResponseData](docs/Jettison200ResponseData.md)
 - [JettisonRequest](docs/JettisonRequest.md)
 - [JumpGate](docs/JumpGate.md)
 - [JumpShip200Response](docs/JumpShip200Response.md)
 - [JumpShip200ResponseData](docs/JumpShip200ResponseData.md)
 - [JumpShipRequest](docs/JumpShipRequest.md)
 - [Market](docs/Market.md)
 - [MarketTradeGood](docs/MarketTradeGood.md)
 - [MarketTransaction](docs/MarketTransaction.md)
 - [Meta](docs/Meta.md)
 - [NavigateShip200Response](docs/NavigateShip200Response.md)
 - [NavigateShip200ResponseData](docs/NavigateShip200ResponseData.md)
 - [NavigateShipRequest](docs/NavigateShipRequest.md)
 - [OrbitShip200Response](docs/OrbitShip200Response.md)
 - [OrbitShip200ResponseData](docs/OrbitShip200ResponseData.md)
 - [PatchShipNavRequest](docs/PatchShipNavRequest.md)
 - [PurchaseCargo201Response](docs/PurchaseCargo201Response.md)
 - [PurchaseCargoRequest](docs/PurchaseCargoRequest.md)
 - [PurchaseShip201Response](docs/PurchaseShip201Response.md)
 - [PurchaseShip201ResponseData](docs/PurchaseShip201ResponseData.md)
 - [PurchaseShipRequest](docs/PurchaseShipRequest.md)
 - [RefuelShip200Response](docs/RefuelShip200Response.md)
 - [RefuelShip200ResponseData](docs/RefuelShip200ResponseData.md)
 - [Register201Response](docs/Register201Response.md)
 - [Register201ResponseData](docs/Register201ResponseData.md)
 - [RegisterRequest](docs/RegisterRequest.md)
 - [ScannedShip](docs/ScannedShip.md)
 - [ScannedShipEngine](docs/ScannedShipEngine.md)
 - [ScannedShipFrame](docs/ScannedShipFrame.md)
 - [ScannedShipMountsInner](docs/ScannedShipMountsInner.md)
 - [ScannedShipReactor](docs/ScannedShipReactor.md)
 - [ScannedSystem](docs/ScannedSystem.md)
 - [ScannedWaypoint](docs/ScannedWaypoint.md)
 - [SellCargo201Response](docs/SellCargo201Response.md)
 - [SellCargo201ResponseData](docs/SellCargo201ResponseData.md)
 - [SellCargoRequest](docs/SellCargoRequest.md)
 - [Ship](docs/Ship.md)
 - [ShipCargo](docs/ShipCargo.md)
 - [ShipCargoItem](docs/ShipCargoItem.md)
 - [ShipCrew](docs/ShipCrew.md)
 - [ShipEngine](docs/ShipEngine.md)
 - [ShipFrame](docs/ShipFrame.md)
 - [ShipFuel](docs/ShipFuel.md)
 - [ShipFuelConsumed](docs/ShipFuelConsumed.md)
 - [ShipModule](docs/ShipModule.md)
 - [ShipMount](docs/ShipMount.md)
 - [ShipNav](docs/ShipNav.md)
 - [ShipNavFlightMode](docs/ShipNavFlightMode.md)
 - [ShipNavRoute](docs/ShipNavRoute.md)
 - [ShipNavRouteWaypoint](docs/ShipNavRouteWaypoint.md)
 - [ShipNavStatus](docs/ShipNavStatus.md)
 - [ShipReactor](docs/ShipReactor.md)
 - [ShipRefine200Response](docs/ShipRefine200Response.md)
 - [ShipRefine200ResponseData](docs/ShipRefine200ResponseData.md)
 - [ShipRefine200ResponseDataProducedInner](docs/ShipRefine200ResponseDataProducedInner.md)
 - [ShipRefineRequest](docs/ShipRefineRequest.md)
 - [ShipRegistration](docs/ShipRegistration.md)
 - [ShipRequirements](docs/ShipRequirements.md)
 - [ShipRole](docs/ShipRole.md)
 - [ShipType](docs/ShipType.md)
 - [Shipyard](docs/Shipyard.md)
 - [ShipyardShip](docs/ShipyardShip.md)
 - [ShipyardShipTypesInner](docs/ShipyardShipTypesInner.md)
 - [ShipyardTransaction](docs/ShipyardTransaction.md)
 - [Survey](docs/Survey.md)
 - [SurveyDeposit](docs/SurveyDeposit.md)
 - [System](docs/System.md)
 - [SystemFaction](docs/SystemFaction.md)
 - [SystemType](docs/SystemType.md)
 - [SystemWaypoint](docs/SystemWaypoint.md)
 - [TradeGood](docs/TradeGood.md)
 - [TradeSymbol](docs/TradeSymbol.md)
 - [TransferCargo200Response](docs/TransferCargo200Response.md)
 - [TransferCargoRequest](docs/TransferCargoRequest.md)
 - [Waypoint](docs/Waypoint.md)
 - [WaypointFaction](docs/WaypointFaction.md)
 - [WaypointOrbital](docs/WaypointOrbital.md)
 - [WaypointTrait](docs/WaypointTrait.md)
 - [WaypointType](docs/WaypointType.md)


## Documentation For Authorization



### AgentToken

- **Type**: HTTP Bearer token authentication

Example

```golang
auth := context.WithValue(context.Background(), sw.ContextAccessToken, "BEARER_TOKEN_STRING")
r, err := client.Service.Operation(auth, args)
```


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author

joel@spacetraders.io

